@@ -596,7 +596,7 @@ int default_mode;			/* Default mode = [DEF_CURRENT, */
 	/*
 	 *  Get the current time/date and local timezone for later use.
 	 */
-#if	HPUX | SGI | SOLARIS | SYS52 
+#if	HPUX | SGI | SOLARIS | SYS52 | LINUX
 	time (&timeinsecs);		/* Get current time */
 	tzset();			/* Get local timezone */
 	local_zone = timezone / 60;	/* Timezone in minutes west from GMT */
