@@ -1754,7 +1754,7 @@ static void shoquetime (que_descr)
 struct gendescr *que_descr;
 {
 	printf ("  Cumulative system space time = ");
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 	printf ("%ld.%02d seconds\n", que_descr->v.que.ru_stime / CPU_MEAS_GRAN,
 		((que_descr->v.que.ru_stime % CPU_MEAS_GRAN) * 100) /
 		CPU_MEAS_GRAN);
@@ -1767,7 +1767,7 @@ BSD SYSTEM TYPE
 #endif
 #endif
 	printf ("  Cumulative user space time = ");
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 	printf ("%ld.%02d seconds\n", que_descr->v.que.ru_utime / CPU_MEAS_GRAN,
 		((que_descr->v.que.ru_utime % CPU_MEAS_GRAN) * 100) /
 		CPU_MEAS_GRAN);
