@@ -92,7 +92,7 @@ typedef struct {
     int	    len_addr;
 } ss_list;
 #else
-#if     BSD43 | ULTRIX | HPUX | SGI | SYS52 
+#if     BSD43 | ULTRIX | HPUX | SGI | SYS52 | LINUX
 #include <sys/dir.h>
 #else
 #if	IBMRS | DECOSF | SOLARIS
