@@ -238,7 +238,7 @@ char *envp [];
 #if	SYS52 
 	setvbuf (Logfile, _IOFBF, Logfile_buffer, BUFSIZ);
 #else
-#if	IBMRS | SGI | SOLARIS | HPUX
+#if	IBMRS | SGI | SOLARIS | HPUX | LINUX
 	setvbuf (Logfile, Logfile_buffer, _IOFBF, BUFSIZ);
 #else
 BAD SYSTEM TYPE
