@@ -150,13 +150,13 @@ static int start_network_daemon (/* void */);
 #endif /* __CEXTRACT__ */
 
 
-#if     SOLARIS
+#if     SOLARIS | LINUX
 #include <sys/time.h>
 #include <sys/resource.h>
 #endif
 #if	BSD43 | ULTRIX | DECOSF
 #else
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
 #define DEFAULT_TZ_SIZE 128		/* Size of default_tz buffer */
 extern int putenv();			/* Add environment variable */
 extern long timezone;			/* Number of seconds from GMT */
@@ -178,7 +178,7 @@ void nqs_boot()
 #if	BSD43 | ULTRIX | DECOSF
 	char *new_envp [1];		/* SUbordinate daemons' environment */
 #else
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
 	static char default_tz [DEFAULT_TZ_SIZE];
 					/* Default timezone environment var */
 	char *new_envp [2];		/* Subordinate daemons' environment */
@@ -225,7 +225,7 @@ BAD SYSTEM TYPE
 #if	BSD43 | ULTRIX | DECOSF
 	signal (SIGTERM, SIG_IGN);
 #else
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
 	signal (SIGTERM, SIG_IGN);
 	signal (SIGUSR1, SIG_IGN);
 	signal (SIGUSR2, SIG_IGN);
@@ -258,7 +258,7 @@ BAD SYSTEM TYPE
 		errno = 0;			/* Not a system call error */
 		nqs_abort();
 	}
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
 	/*
 	 *  System V based implementations of NQS require the presence
 	 *  of the TZ environment variable.  This is used in
@@ -465,7 +465,7 @@ BAD SYSTEM TYPE
 	    nqs_abort();
 	}
 	relfilnam (root_dir);
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | ULTRIX | DECOSF
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | ULTRIX | DECOSF | LINUX
 	/*
 	 *  Check for the possibility of multiple NQS local daemons running.
 	 */
@@ -486,7 +486,7 @@ BAD SYSTEM TYPE
 BAD SYSTEM TYPE
 #endif
 #endif
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | ULTRIX | DECOSF 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | ULTRIX | DECOSF | LINUX
 	/*
 	 *  Create the named pipe that will serve as the "mailbox"
 	 *  for NQS request packets.
@@ -583,7 +583,7 @@ BAD SYSTEM TYPE
 						/* refer to Read_fifo */
 	close (Read_fifo);	/* Don't need original Read_fifo now */
 	Read_fifo = STDIN;	/* Read_fifo is STDIN */
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | ULTRIX | DECOSF 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | ULTRIX | DECOSF | LINUX
         fifo_pipe = getfilnam (Nqs_ffifo, SPOOLDIR);
         if (fifo_pipe == (char *)NULL) {
                 printf ("F$Unable to determine name of FIFO write pipe.\n");
@@ -740,7 +740,7 @@ BAD SYSTEM TYPE
 		nqs_abort();		/* Abort execution */
 	}
 #else
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
 #else
 BAD SYSTEM TYPE
 #endif
@@ -978,7 +978,7 @@ int start_network_daemon()
 #if	BSD43 | ULTRIX | DECOSF
     char *new_envp [4];		        /* Subordinate daemons' environment */
 #else
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
     static char default_tz [DEFAULT_TZ_SIZE];	
 					/* Default timezone environment var */
     char *new_envp [5];		        /* Subordinate daemons' environment */
@@ -1007,7 +1007,7 @@ BAD SYSTEM TYPE
 	new_envp[i++] = envp3_buf;
     }
 
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
 	/*
 	 *  System V based implementations of NQS require the presence
 	 *  of the TZ environment variable.  This is used in
@@ -1137,7 +1137,7 @@ int start_load_daemon()
 #if	BSD43 | ULTRIX | DECOSF
     char *new_envp [4];		        /* Subordinate daemons' environment */
 #else
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
     static char default_tz [DEFAULT_TZ_SIZE];	
 					/* Default timezone environment var */
     char *new_envp [5];		        /* Subordinate daemons' environment */
@@ -1166,7 +1166,7 @@ BAD SYSTEM TYPE
 	new_envp[i++] = envp3_buf;
     }
 
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
     /*
      *  System V based implementations of NQS require the presence
      *  of the TZ environment variable.  This is used in
