@@ -100,7 +100,7 @@
 #if	HPUX
 #include <ndir.h>
 #else
-#if     SOLARIS
+#if     SOLARIS | LINUX
 #include <dirent.h>
 #else
 BAD SYSTEM TYPE
@@ -175,7 +175,7 @@ void nqs_rbuild()
         char *requests_dir;             /* Fully qualified file name */
         char *scripts_dir;              /* Fully qualified file name */
 	DIR *dir;			/* Open queue order dir structure */
-#if	IBMRS | DECOSF | SOLARIS
+#if	IBMRS | DECOSF | SOLARIS | LINUX
 	struct dirent *dirent;		/* Ptr to directory entry */
 #else
 	struct direct *dirent;		/* Ptr to directory entry */
@@ -209,12 +209,12 @@ void nqs_rbuild()
 		nqs_abort();
 	}
         relfilnam (requests_dir);
-#if	IBMRS | DECOSF | SOLARIS
+#if	IBMRS | DECOSF | SOLARIS | LINUX
 	while ((dirent = readdir (dir)) != (struct dirent *) 0) {
 #else
 	while ((dirent = readdir (dir)) != (struct direct *) 0) {
 #endif
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | ULTRIX | DECOSF 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | ULTRIX | DECOSF | LINUX
 		if (!reserved (dirent->d_name) &&
 		    strcmp (dirent->d_name, Nqs_fifo)) {
 #else
@@ -250,7 +250,7 @@ BAD SYSTEM TYPE
 		printf ("process communication directory.\n");
 		nqs_abort();
 	}
-#if	IBMRS | DECOSF | SOLARIS 
+#if	IBMRS | DECOSF | SOLARIS | LINUX
 	while ((dirent = readdir (dir)) != (struct dirent *) 0) {
 #else
 	while ((dirent = readdir (dir)) != (struct direct *) 0) {
@@ -304,7 +304,7 @@ BAD SYSTEM TYPE
 		printf ("F$Unable to open queue ordering directory.\n");
 		nqs_abort();
 	}
-#if	IBMRS | DECOSF | SOLARIS
+#if	IBMRS | DECOSF | SOLARIS | LINUX
 	while ((dirent = readdir (dir)) != (struct dirent *) 0) {
 #else
 	while ((dirent = readdir (dir)) != (struct direct *) 0) {
@@ -332,7 +332,7 @@ BAD SYSTEM TYPE
                 relfilnam (scripts_dir);
                 nqs_abort();
         }
-#if	IBMRS | DECOSF | SOLARIS
+#if	IBMRS | DECOSF | SOLARIS | LINUX
 	while ((dirent = readdir (dir)) != (struct dirent *) 0) {
 #else
 	while ((dirent = readdir (dir)) != (struct direct *) 0) {
@@ -358,7 +358,7 @@ BAD SYSTEM TYPE
 			printf ("F$Unable to open the directory: %s.\n", path);
 			nqs_abort();
 		}
-#if	IBMRS | DECOSF | SOLARIS
+#if	IBMRS | DECOSF | SOLARIS | LINUX
 		while ((dirent = readdir (dir)) != (struct dirent *) 0) {
 #else
 		while ((dirent = readdir (dir)) != (struct direct *) 0) {
@@ -427,7 +427,7 @@ BAD SYSTEM TYPE
 			printf ("F$Unable to open the directory: %s.\n", path);
 			nqs_abort();
 		}
-#if	IBMRS | DECOSF | SOLARIS
+#if	IBMRS | DECOSF | SOLARIS | LINUX
 		while ((dirent = readdir (dir)) != (struct dirent *) 0) {
 #else
 		while ((dirent = readdir (dir)) != (struct direct *) 0) {
@@ -496,7 +496,7 @@ BAD SYSTEM TYPE
 			printf ("F$Unable to open the directory: %s.\n", path);
 			nqs_abort();
 		}
-#if	IBMRS | DECOSF | SOLARIS
+#if	IBMRS | DECOSF | SOLARIS | LINUX
 		while ((dirent = readdir (dir)) != (struct dirent *) 0) {
 #else
 		while ((dirent = readdir (dir)) != (struct direct *) 0) {
