@@ -123,7 +123,7 @@ static long tell_nqs_scheduler (/* int orig_seqno, Mid_t orig_mid, struct reques
  *	void nqs_reqcom():
  *	Process an NQS request completion event.
  */
-#if	HPUX | SGI | SYS52 | IBMRS | SOLARIS
+#if	HPUX | SGI | SYS52 | IBMRS | SOLARIS | LINUX
 void nqs_reqcom (orig_seqno, orig_mid, exitcode, tms, queuename)
 long orig_seqno;			/* Request original sequence# */
 Mid_t orig_mid;				/* Request original machine-id */
@@ -240,7 +240,7 @@ BAD SYSTEM TYPE
 	/*
 	 *  Update resource usage statistics.
 	 */
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 	/*
 	 *  Update system call time.
 	 */
@@ -369,7 +369,7 @@ BAD SYSTEM TYPE
                                 sizeof(acct_fin1.user));
                         strncpy(acct_fin1.queue, serverq->q.namev.name,
                                 sizeof(acct_fin1.queue));
-#if     HPUX | SGI | SOLARIS | SYS52 | IBMRS
+#if     HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
                         acct_fin1.tms_stime = tms->tms_stime + tms->tms_cstime;
                         acct_fin1.tms_utime = tms->tms_utime + tms->tms_cutime;
 #else
