@@ -417,7 +417,7 @@ struct passwd *passwd;			/* Password entry for request */
 			envp [envpcount++] = cp;
 			sprintf (cp, "USERNAME=%s", passwd->pw_name);
 			envpsize += strlen (cp) + 1;
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 			/*
 			 *  Network queue and pipe queue servers for
 			 *  System V based implementations of NQS always
@@ -594,7 +594,7 @@ BAD SYSTEM TYPE
 		envp [envpcount++] = cp;
 		strcpy(cp, get_the_path(passwd) );
 		envpsize += strlen(cp) + 1;				 
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 		cp = environment + envpsize;
 		envp [envpcount++] = cp;
 		sprintf (cp, "LOGNAME=%s", passwd->pw_name) + 1;
@@ -1272,7 +1272,7 @@ BAD SYSTEM TYPE
 #if             BSD43 | ULTRIX | DECOSF
                 enf_bsdnic (rawreq->v.bat.ppnice);
 #else
-#if             HPUX | SGI | SOLARIS | SYS52 | IBMRS
+#if             HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
                 enf_sy5nic (rawreq->v.bat.ppnice);
 #else
 BAD SYSTEM TYPE
@@ -1294,7 +1294,7 @@ BAD SYSTEM TYPE
 		 *  while we're still root.
 		 */
 #if		(VALID_LIMITS & LIM_PPCORE)
-#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS
+#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS | LINUX
 		enf_bsdquo (&rawreq->v.bat.ppcoresize,
 			    rawreq->v.bat.infinite & LIM_PPCORE, LIM_PPCORE);
 #else
@@ -1306,7 +1306,7 @@ BAD SYSTEM TYPE
 #endif
 
 #if		(VALID_LIMITS & LIM_PPDATA)
-#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS
+#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS | LINUX
 		enf_bsdquo (&rawreq->v.bat.ppdatasize,
 			    rawreq->v.bat.infinite & LIM_PPDATA, LIM_PPDATA);
 #else
@@ -1322,7 +1322,7 @@ BAD SYSTEM TYPE
 		enf_bsdquo (&rawreq->v.bat.pppfilesize,
 			    rawreq->v.bat.infinite & LIM_PPPFILE, LIM_PPPFILE);
 #else
-#if		HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if		HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 		enf_sy5quo (&rawreq->v.bat.pppfilesize,
 			    rawreq->v.bat.infinite & LIM_PPPFILE, LIM_PPPFILE);
 #else
@@ -1332,7 +1332,7 @@ BAD SYSTEM TYPE
 #endif
 
 #if		(VALID_LIMITS & LIM_PPSTACK)
-#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS
+#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS | LINUX
 		enf_bsdquo (&rawreq->v.bat.ppstacksize,
 			    rawreq->v.bat.infinite & LIM_PPSTACK, LIM_PPSTACK);
 #else
@@ -1344,7 +1344,7 @@ BAD SYSTEM TYPE
 #endif
 
 #if		(VALID_LIMITS & LIM_PPWORK)
-#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS
+#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS | LINUX
 		enf_bsdquo (&rawreq->v.bat.ppworkset,
 			    rawreq->v.bat.infinite & LIM_PPWORK, LIM_PPWORK);
 #else
@@ -1356,7 +1356,7 @@ BAD SYSTEM TYPE
 #endif
 
 #if		(VALID_LIMITS & LIM_PPCPUT)
-#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS
+#if		HPUX | SGI | SOLARIS | BSD43 | ULTRIX | DECOSF | IBMRS | LINUX
 		enf_bsdcpu (&rawreq->v.bat.ppcputime,
 			    rawreq->v.bat.infinite & LIM_PPCPUT, LIM_PPCPUT);
 #else
@@ -1440,7 +1440,9 @@ BAD SYSTEM TYPE
 	signal (SIGILL, SIG_DFL);
 	signal (SIGTRAP, SIG_DFL);
 	signal (SIGIOT, SIG_DFL);
+#if !LINUX
 	signal (SIGEMT, SIG_DFL);
+#endif
 	signal (SIGFPE, SIG_DFL);
 	signal (SIGBUS, SIG_DFL);
 	signal (SIGSEGV, SIG_DFL);
@@ -1449,7 +1451,7 @@ BAD SYSTEM TYPE
 	signal (SIGALRM, SIG_DFL);
 	if (queue->q.type == QUE_BATCH) signal (SIGTERM, SIG_IGN);
 	else signal (SIGTERM, SIG_DFL);
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 	signal (SIGUSR1, SIG_DFL);
 	signal (SIGUSR2, SIG_DFL);
 	signal (SIGCLD, SIG_DFL);
@@ -1907,7 +1909,7 @@ struct passwd    *passwd;
 	 *  We are running as root.  The default path
 	 *  is slightly different.
 	 */
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 	strcpy (the_path,  "PATH=/bin:/etc:/usr/bin");
      } else {
 	/*
