@@ -277,7 +277,7 @@ int queldb;                     /* Queue load balancing flags */
 	queue->q.priority = quepriority;/* Assign priority */
 	queue->q.ndp = quendp;		/* assign ndp */
 	strcpy (queue->q.namev.name, quename);	/* Remember queue name */
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 	queue->q.ru_stime = 0;		/* No clock ticks yet consumed */
 	queue->q.ru_utime = 0;
 #else
