@@ -276,7 +276,7 @@ char *envp[];				/* Environment */
 		"QSUB_HOST",
 		"QSUB_REQID",
 		"QSUB_REQNAME",
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
 		"QSUB_LOGNAME",
 #else
 #if	BSD43 | ULTRIX | DECOSF
@@ -882,7 +882,7 @@ BAD SYSTEM TYPE
 	if ((cp = getenv ("PATH")) != NULL) {
 		fprintf (ctrlfile, "E%s=%s\n", "QSUB_PATH", cp);
 	}
-#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS 
+#if	SGI | SOLARIS | HPUX | SYS52 | IBMRS | LINUX
 	if ((cp = getenv ("LOGNAME")) != NULL) {
 		fprintf (ctrlfile, "E%s=%s\n", "QSUB_LOGNAME", cp);
 	}
